@@ -47,7 +47,7 @@ __END__
 
 =head1 NAME
 
-Mojolicious::Plugin::Util::Endpoint::endpoints - Show Template URIs
+Mojolicious::Plugin::Util::Endpoint::endpoints - List Template URIs
 
 =head1 SYNOPSIS
 
@@ -59,7 +59,7 @@ Mojolicious::Plugin::Util::Endpoint::endpoints - Show Template URIs
 
 =head1 DESCRIPTION
 
-L<Mojolicious::Plugin::Util::Endpoint::endpoints> shows all
+L<Mojolicious::Plugin::Util::Endpoint::endpoints> lists all
 endpoints established by L<Mojolicious::Plugin::Util::Endpoint>.
 
 It is normally started from the command line:
@@ -116,7 +116,7 @@ L<Mojolicious::Plugin::Util::Endpoint>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2013, L<Nils Diewald|http://nils-diewald.de/>.
+Copyright (C) 2012-2014, L<Nils Diewald|http://nils-diewald.de/>.
 
 This program is free software, you can redistribute it
 and/or modify it under the same terms as Perl.
